summaryrefslogtreecommitdiffstats
path: root/smb4k/dialogs/smb4kcustomoptionsdialog.h
diff options
context:
space:
mode:
Diffstat (limited to 'smb4k/dialogs/smb4kcustomoptionsdialog.h')
-rw-r--r--smb4k/dialogs/smb4kcustomoptionsdialog.h27
1 files changed, 14 insertions, 13 deletions
diff --git a/smb4k/dialogs/smb4kcustomoptionsdialog.h b/smb4k/dialogs/smb4kcustomoptionsdialog.h
index 10594a9..00c6123 100644
--- a/smb4k/dialogs/smb4kcustomoptionsdialog.h
+++ b/smb4k/dialogs/smb4kcustomoptionsdialog.h
@@ -31,8 +31,8 @@
#include <config.h>
#endif
-// Qt includes
-#include <qcheckbox.h>
+// TQt includes
+#include <tqcheckbox.h>
// KDE includes
#include <kdialogbase.h>
@@ -47,6 +47,7 @@ class Smb4KShareItem;
class Smb4KCustomOptionsDialog : public KDialogBase
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
@@ -54,22 +55,22 @@ class Smb4KCustomOptionsDialog : public KDialogBase
*
* @param host The host (server) for which the custom options should be defined.
*
* @param parent The parent of this dialog
*
* @param name The name of this dialog
*/
- Smb4KCustomOptionsDialog( Smb4KHostItem *host, QWidget *parent = 0, const char *name = 0 );
+ Smb4KCustomOptionsDialog( Smb4KHostItem *host, TQWidget *tqparent = 0, const char *name = 0 );
/**
* Another constructor, similar to the one above.
*
* @param share The share for which the custom options should be defined.
*
* @param parent The parent of this dialog
*
* @param name The name of this dialog
*/
- Smb4KCustomOptionsDialog( Smb4KShareItem *share, QWidget *parent = 0, const char *name = 0 );
+ Smb4KCustomOptionsDialog( Smb4KShareItem *share, TQWidget *tqparent = 0, const char *name = 0 );
/**
* The destructor
@@ -99,14 +100,14 @@ class Smb4KCustomOptionsDialog : public KDialogBase
*
* @param fs The file system
*/
- void slotFilesystemChanged( const QString &fs );
+ void slotFilesystemChanged( const TQString &fs );
/**
* Is invoked when the protocol value changed
*
* @param t The protocol
*/
- void slotProtocolChanged( const QString &p );
+ void slotProtocolChanged( const TQString &p );
/**
* Is invoked when the user clicked the 'Use Kerberos'
@@ -133,21 +134,21 @@ class Smb4KCustomOptionsDialog : public KDialogBase
*
* @param rw Either 'read-write' or 'read-only' (localized).
*/
- void slotWriteAccessChanged( const QString &rw );
+ void slotWriteAccessChanged( const TQString &rw );
/**
* This slot is invoked when the UID value changed.
*
* @param uid The UID value
*/
- void slotUIDChanged( const QString &uid );
+ void slotUIDChanged( const TQString &uid );
/**
* This slot is invoked when the GID value changed.
*
* @param gid The UID value
*/
- void slotGIDChanged( const QString &gid );
+ void slotGIDChanged( const TQString &gid );
private:
/**
@@ -207,14 +208,14 @@ class Smb4KCustomOptionsDialog : public KDialogBase
/**
* This will only be set if we are dealing with a 'homes' share.
*/
- QString m_homes_user;
+ TQString m_homes_user;
/**
* This check box will determine if the user wants to try to
* authenticate with Kerberos or not. This is needed for Active
* Directory stuff.
*/
- QCheckBox *m_kerberos;
+ TQCheckBox *m_kerberos;
/**
* This combo box holds the values of the UID that the user can
@@ -54,22 +55,22 @@ class Smb4KCustomOptionsDialog : public KDialogBase
* @param host The host (server) for which the custom options should be defined.
*
- * @param parent The parent of this dialog
+ * @param tqparent The tqparent of this dialog
*
* @param name The name of this dialog
@@ -54,22 +55,22 @@ class Smb4KCustomOptionsDialog : public KDialogBase
* @param share The share for which the custom options should be defined.
*
- * @param parent The parent of this dialog
+ * @param tqparent The tqparent of this dialog
*
* @param name The name of this dialog